@@ -1,6 +1,9 @@
-use glib::subclass::prelude::*;
+use glib::{prelude::*, subclass::prelude::*};
 
 use crate::{subclass::fd_allocator::FdAllocatorImpl, DmaBufAllocator};
 
-pub trait DmaBufAllocatorImpl: FdAllocatorImpl {}
+pub trait DmaBufAllocatorImpl:
+    FdAllocatorImpl + ObjectSubclass<Type: IsA<DmaBufAllocator>>
+{
+}
 unsafe impl<T: DmaBufAllocatorImpl> IsSubclassable<T> for DmaBufAllocator {}
