@@ -1,7 +1,7 @@
-use glib::subclass::prelude::*;
+use glib::{prelude::*, subclass::prelude::*};
 
 use crate::FdAllocator;
 use gst::subclass::prelude::AllocatorImpl;
 
-pub trait FdAllocatorImpl: AllocatorImpl {}
+pub trait FdAllocatorImpl: AllocatorImpl + ObjectSubclass<Type: IsA<FdAllocator>> {}
 unsafe impl<T: FdAllocatorImpl> IsSubclassable<T> for FdAllocator {}
